@@ -1,10 +1,14 @@
 //! `SocketpairStream` and `socketpair_stream` for Posix-ish platforms.
 
+use io_extras::os::rustix::{
+    AsRawFd, AsRawReadWriteFd, AsReadWriteFd, FromRawFd, IntoRawFd, RawFd,
+};
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
+#[cfg(not(any(target_os = "ios", target_os = "macos")))]
+use rustix::net::{AddressFamily, Protocol, SocketFlags, SocketType};
 use std::fmt::{self, Arguments, Debug};
 use std::io::{self, IoSlice, IoSliceMut, Read, Write};
 use std::os::unix::net::UnixStream;
-use unsafe_io::os::rsix::{AsRawFd, AsRawReadWriteFd, AsReadWriteFd, FromRawFd, IntoRawFd, RawFd};
 #[cfg(not(unix_socket_peek))]
 use {io_lifetimes::AsSocketlike, std::net::TcpStream};
 
@@ -39,7 +43,7 @@ impl SocketpairStream {
     /// Return the number of bytes which are ready to be read immediately.
     #[inline]
     pub fn num_ready_bytes(&self) -> io::Result<u64> {
-        Ok(rsix::io::ioctl_fionread(self)?)
+        Ok(rustix::io::ioctl_fionread(self)?)
     }
 }
 
@@ -49,6 +53,27 @@ pub fn socketpair_stream() -> io::Result<(SocketpairStream, SocketpairStream)> {
     UnixStream::pair().map(|(a, b)| (SocketpairStream(a), SocketpairStream(b)))
 }
 
+/// Create a socketpair and return seqpacket handles connected to each end.
+///
+/// Note that this is not available on macOS or ios due to missing OS support
+/// for `SOCK_SEQPACKET` with `AF_UNIX`.
+#[cfg(not(any(target_os = "ios", target_os = "macos")))]
+#[inline]
+pub fn socketpair_seqpacket() -> io::Result<(SocketpairStream, SocketpairStream)> {
+    let (a, b) = rustix::net::socketpair(
+        AddressFamily::UNIX,
+        SocketType::SEQPACKET,
+        SocketFlags::CLOEXEC,
+        Protocol::default(),
+    )?;
+    unsafe {
+        Ok((
+            SocketpairStream::from_raw_fd(a.into_raw_fd()),
+            SocketpairStream::from_raw_fd(b.into_raw_fd()),
+        ))
+    }
+}
+
 impl Read for SocketpairStream {
     #[inline]
     fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
