@@ -3,11 +3,13 @@
 
 use async_std::io::{self, IoSlice, IoSliceMut, Read, Write};
 use async_std::os::unix::net::UnixStream;
+use io_extras::os::rustix::{
+    AsRawFd, AsRawReadWriteFd, AsReadWriteFd, FromRawFd, IntoRawFd, RawFd,
+};
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 use std::fmt::{self, Debug};
 use std::pin::Pin;
 use std::task::{Context, Poll};
-use unsafe_io::os::rsix::{AsRawFd, AsRawReadWriteFd, AsReadWriteFd, FromRawFd, IntoRawFd, RawFd};
 
 /// A socketpair stream, which is a bidirectional bytestream much like a
 /// [`UnixStream`] except that it does not have a name or address.
@@ -30,7 +32,7 @@ impl AsyncStdSocketpairStream {
     /// Return the number of bytes which are ready to be read immediately.
     #[inline]
     pub fn num_ready_bytes(&self) -> io::Result<u64> {
-        Ok(rsix::io::ioctl_fionread(self)?)
+        Ok(rustix::io::ioctl_fionread(self)?)
     }
 }
 
